@@ -227,7 +227,7 @@ describe 'horizon::wsgi::apache' do
         params.merge!({
           :extra_params  => {
             'add_listen' => false,
-            'docroot'    => '/tmp'
+            'docroot' => '/tmp'
           },
         })
       end
@@ -236,30 +236,6 @@ describe 'horizon::wsgi::apache' do
         :add_listen => false,
         :docroot    => '/tmp'
       )}
-      it { should contain_apache__vhost('horizon_ssl_vhost').with(
-        :add_listen => false,
-        :docroot    => '/tmp'
-      )}
-    end
-
-    context 'with ssl extra parameters' do
-      before do
-        params.merge!({
-          :extra_params  => {
-            'docroot' => '/root1'
-          },
-          :ssl_extra_params  => {
-            'docroot' => '/root2'
-          },
-        })
-      end
-
-      it { should contain_apache__vhost('horizon_vhost').with(
-        :docroot => '/root1'
-      )}
-      it { should contain_apache__vhost('horizon_ssl_vhost').with(
-        :docroot => '/root2'
-      )}
     end
 
     context 'with root_url set to /' do
@@ -544,10 +520,6 @@ describe 'horizon::wsgi::apache' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        if facts[:operatingsystem] == 'Debian'
-          facts.merge!( :os_package_type => 'debian' )
-        end
-
         facts.merge!(OSDefaults.get_facts({
           :fqdn           => 'some.host.tld',
           :concat_basedir => '/var/lib/puppet/concat',
